@@ -310,11 +310,11 @@ class Mdadm(object):
             raidDevs.append(dev["device"])
         outDel = exececute("mdadm --stop %s" % device.device)
         if outDel.rc != 0:
-            raise MdadmCreateRaidException("Cannot stop Raid. STDOUT: %s STDERR: %s" % (outDel.stdout, outDel.stderr))
+            raise MdadmDeleteRaidException("Cannot stop Raid. STDOUT: %s STDERR: %s" % (outDel.stdout, outDel.stderr))
         if zero:
             outZero = exececute("mdadm --zero-superblock %s" % " ".join(raidDevs))
             if outZero.rc != 0:
-                raise MdadmCreateRaidException("Cannot zero superbolocks. STDOUT: %s STDERR: %s" % (outZero.stdout, outZero.stderr))
+                raise MdadmDeleteRaidException("Cannot zero superbolocks. STDOUT: %s STDERR: %s" % (outZero.stdout, outZero.stderr))
 
 
     def _checkPart(self, devices=[]):
